==> pvOps-0.1.0.tar.gz: pvOps-0.1.0/README.md <==
# pvOps
pvOps contains a series of functions to facilitate fusion of text-based data with time series production data collected at photovoltaic sites. The package also contains example datasets and tutorials to help demonstrate how the functions can be used.

Installation
=============
pvOps can be installed using `pip`. See more information at [readthedocs](https://pvops.readthedocs.io/en/latest/).


Package Layout and Documentation
==============

The package is delineated into the following directories. Refer to the `examples` directory for a full run-through of the available functionality.
```
├───docs                : Documentation directory
|
├───examples            : Functionality examples directory
│   └─── example_data   : └─── Example data
|
└───pvops               : Source function library
    ├───tests           : ├─── Library stability tests
    ├───text            : ├─── Text processing functions
    └───text2time       : └─── Text2Timeseries functions
```

More information about theses modules is available in the documentation at [readthedocs](https://pvops.readthedocs.io/en/latest/).

Contributing
============

The long-term success of pvOps requires community support. Please see the [Contributing page](https://pvops.readthedocs.io/en/latest/) for more on how you can contribute.


Copyright and License
=======

pvOps is copyright through Sandia National Laboratories. The software is distributed under the Revised BSD License. See [copyright and license](https://github.com/tgunda/pvOps/blob/master/LICENSE) for more information.

==> pvOps-0.1.1.tar.gz: pvOps-0.1.1/README.md <==
# pvOps
pvOps contains a series of functions to facilitate fusion of text-based data with time series production data collected at photovoltaic sites. The package also contains example datasets and tutorials to help demonstrate how the functions can be used.

Installation
=============
pvOps can be installed using `pip`. See more information at [readthedocs](https://pvops.readthedocs.io/en/latest/).


Package Layout and Documentation
==============

The package is delineated into the following directories. Refer to the `examples` directory for a full run-through of the available functionality.
```
├───docs                : Documentation directory
|
├───examples            : Functionality examples directory
│   └─── example_data   : └─── Example data
|
└───pvOps               : Source function library
    ├───tests           : ├─── Library stability tests
    ├───text            : ├─── Text processing functions
    └───text2time       : └─── Text2Timeseries functions
```

More information about theses modules is available in the documentation at [readthedocs](https://pvops.readthedocs.io/en/latest/).

Contributing
============

The long-term success of pvOps requires community support. Please see the [Contributing page](https://pvops.readthedocs.io/en/latest/) for more on how you can contribute.


Copyright and License
=======

pvOps is copyright through Sandia National Laboratories. The software is distributed under the Revised BSD License. See [copyright and license](https://github.com/tgunda/pvOps/blob/master/LICENSE) for more information.
